@@ -1,7 +1,7 @@
 runSurface<-
 function(tree,dat,exclude=0,aic_threshold=0,max_steps=NULL, verbose=FALSE, plotaic = FALSE,error_skip=FALSE,only_best=FALSE,sample_shifts=FALSE, sample_threshold=2){
 
-if(class(tree)!="phylo") stop("'tree' must by a 'phylo' formatted phylogenetic tree")
+if(!inherits(tree,"phylo")) stop("'tree' must by a 'phylo' formatted phylogenetic tree")
 
 if(is.null(tree$node.label))
 	stop("Each node in 'tree' must have a unique label for back-compatibility between formats. Use 'nameNodes(tree)'. ")
